@@ -32,6 +32,7 @@ __all__ = (
     "DelegateTypeDef",
     "FolderConfigurationTypeDef",
     "GroupTypeDef",
+    "MailboxExportJobTypeDef",
     "MemberTypeDef",
     "OrganizationSummaryTypeDef",
     "PermissionTypeDef",
@@ -42,6 +43,7 @@ __all__ = (
     "CreateResourceResponseTypeDef",
     "CreateUserResponseTypeDef",
     "DescribeGroupResponseTypeDef",
+    "DescribeMailboxExportJobResponseTypeDef",
     "DescribeOrganizationResponseTypeDef",
     "DescribeResourceResponseTypeDef",
     "DescribeUserResponseTypeDef",
@@ -52,6 +54,7 @@ __all__ = (
     "ListAliasesResponseTypeDef",
     "ListGroupMembersResponseTypeDef",
     "ListGroupsResponseTypeDef",
+    "ListMailboxExportJobsResponseTypeDef",
     "ListMailboxPermissionsResponseTypeDef",
     "ListOrganizationsResponseTypeDef",
     "ListResourceDelegatesResponseTypeDef",
@@ -59,6 +62,7 @@ __all__ = (
     "ListTagsForResourceResponseTypeDef",
     "ListUsersResponseTypeDef",
     "PaginatorConfigTypeDef",
+    "StartMailboxExportJobResponseTypeDef",
 )
 
 AccessControlRuleTypeDef = TypedDict(
@@ -122,6 +126,22 @@ GroupTypeDef = TypedDict(
     total=False,
 )
 
+MailboxExportJobTypeDef = TypedDict(
+    "MailboxExportJobTypeDef",
+    {
+        "JobId": str,
+        "EntityId": str,
+        "Description": str,
+        "S3BucketName": str,
+        "S3Path": str,
+        "EstimatedProgress": int,
+        "State": Literal["RUNNING", "COMPLETED", "FAILED", "CANCELLED"],
+        "StartTime": datetime,
+        "EndTime": datetime,
+    },
+    total=False,
+)
+
 MemberTypeDef = TypedDict(
     "MemberTypeDef",
     {
@@ -202,6 +222,25 @@ DescribeGroupResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeMailboxExportJobResponseTypeDef = TypedDict(
+    "DescribeMailboxExportJobResponseTypeDef",
+    {
+        "EntityId": str,
+        "Description": str,
+        "RoleArn": str,
+        "KmsKeyArn": str,
+        "S3BucketName": str,
+        "S3Prefix": str,
+        "S3Path": str,
+        "EstimatedProgress": int,
+        "State": Literal["RUNNING", "COMPLETED", "FAILED", "CANCELLED"],
+        "ErrorInfo": str,
+        "StartTime": datetime,
+        "EndTime": datetime,
+    },
+    total=False,
+)
+
 DescribeOrganizationResponseTypeDef = TypedDict(
     "DescribeOrganizationResponseTypeDef",
     {
@@ -289,6 +328,12 @@ ListGroupsResponseTypeDef = TypedDict(
     "ListGroupsResponseTypeDef", {"Groups": List["GroupTypeDef"], "NextToken": str}, total=False
 )
 
+ListMailboxExportJobsResponseTypeDef = TypedDict(
+    "ListMailboxExportJobsResponseTypeDef",
+    {"Jobs": List["MailboxExportJobTypeDef"], "NextToken": str},
+    total=False,
+)
+
 ListMailboxPermissionsResponseTypeDef = TypedDict(
     "ListMailboxPermissionsResponseTypeDef",
     {"Permissions": List["PermissionTypeDef"], "NextToken": str},
@@ -324,3 +369,7 @@ ListUsersResponseTypeDef = TypedDict(
 PaginatorConfigTypeDef = TypedDict(
     "PaginatorConfigTypeDef", {"MaxItems": int, "PageSize": int, "StartingToken": str}, total=False
 )
+
+StartMailboxExportJobResponseTypeDef = TypedDict(
+    "StartMailboxExportJobResponseTypeDef", {"JobId": str}, total=False
+)
